@@ -1,3 +1,4 @@
+from __future__ import unicode_literals
 import re
 
 # Testaments, Book Name, Osis Abbreviation (Also preferred abbreviation), Regex,
@@ -61,7 +62,7 @@ testaments = {'ot': (
 ('I Timothy', '1Tim', '(?:1|I)(?:\s)?Tim(?:othy)?', [20, 15, 16, 16, 25, 21]),
 ('II Timothy', '2Tim', '(?:2|II)(?:\s)?Tim(?:othy)?', [18, 26, 17, 22]),
 ('Titus', 'Titus', 'Tit(?:us)?', [16, 15, 15]),
-('Philemon', 'Phlm', 'Phile(?:mon)?', [25]),
+('Philemon', 'Phlm', 'Phlm|Phile(?:mon)?', [25]),
 ('Hebrews', 'Heb', 'Heb(?:rews)?', [14, 18, 19, 16, 14, 20, 28, 13, 28, 39, 40, 29, 25]),
 ('James', 'Jas', 'Ja(?:me)?s', [27, 26, 18, 17, 20]),
 ('I Peter', '1Pet', '(?:1|I)(?:\s)?Pet(?:er)?', [25, 25, 22, 19, 14]),
@@ -87,16 +88,16 @@ def get_book_re():
 book_re_string=get_book_re()
 
 # compiled book regular expression
-book_re = re.compile(book_re_string, re.IGNORECASE)
+book_re = re.compile(book_re_string, re.IGNORECASE | re.UNICODE)
 
 # compiled scripture reference regular expression
 scripture_re = re.compile(
     r'\b(?P<BookTitle>%s)\s*' \
      '(?P<ChapterNumber>\d{1,3})' \
      '(?:\s*:\s*(?P<VerseNumber>\d{1,3}))?' \
-     '(?:\s*-\s*' \
+     '(?:\s*[-\u2013\u2014]\s*' \
      '(?P<EndChapterNumber>\d{1,3}(?=\s*:\s*))?' \
      '(?:\s*:\s*)?' \
      '(?P<EndVerseNumber>\d{1,3})?' \
-     ')?' % (book_re_string,), re.IGNORECASE)
+     ')?' % (book_re_string,), re.IGNORECASE | re.UNICODE)
 
